==> lokinet-docs-v0.9.9.tar.xz: lokinet-docs-v0.9.9/markdown/Files/rr_8hpp.md <==
---
title: llarp/dns/rr.hpp

---

# llarp/dns/rr.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::dns](Namespaces/namespacellarp_1_1dns.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| struct | **[llarp::dns::ResourceRecord](Classes/structllarp_1_1dns_1_1ResourceRecord.md)**  |




## Source code

```cpp
#pragma once

#include "name.hpp"
#include "serialize.hpp"
#include <llarp/net/net_int.hpp>

#include <memory>
#include <vector>

namespace llarp
{
  namespace dns
  {
    using RRClass_t = uint16_t;
    using RRType_t = uint16_t;
    using RR_RData_t = std::vector<byte_t>;
    using RR_TTL_t = uint32_t;

    struct ResourceRecord : public Serialize
    {
      ResourceRecord() = default;
      ResourceRecord(const ResourceRecord& other);
      ResourceRecord(ResourceRecord&& other);

      explicit ResourceRecord(Name_t name, RRType_t type, RR_RData_t rdata);

      bool
      Encode(llarp_buffer_t* buf) const override;

      bool
      Decode(llarp_buffer_t* buf) override;

      util::StatusObject
      ToJSON() const override;

      std::ostream&
      print(std::ostream& stream, int level, int spaces) const;

      bool
      HasCNameForTLD(const std::string& tld) const;

      Name_t rr_name;
      RRType_t rr_type;
      RRClass_t rr_class;
      RR_TTL_t ttl;
      RR_RData_t rData;
    };

    inline std::ostream&
    operator<<(std::ostream& out, const ResourceRecord& rr)
    {
      return rr.print(out, -1, -1);
    }
  }  // namespace dns
}  // namespace llarp
```


-------------------------------

Updated on 2022-05-31 at 02:25:20 +0000

==> lokinet-docs-v0.9.11.tar.xz: lokinet-docs-v0.9.11/markdown/Files/rr_8hpp.md <==
---
title: llarp/dns/rr.hpp

---

# llarp/dns/rr.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::dns](Namespaces/namespacellarp_1_1dns.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| struct | **[llarp::dns::ResourceRecord](Classes/structllarp_1_1dns_1_1ResourceRecord.md)**  |




## Source code

```cpp
#pragma once

#include "name.hpp"
#include "serialize.hpp"
#include <llarp/net/net_int.hpp>

#include <memory>
#include <vector>

namespace llarp
{
  namespace dns
  {
    using RRClass_t = uint16_t;
    using RRType_t = uint16_t;
    using RR_RData_t = std::vector<byte_t>;
    using RR_TTL_t = uint32_t;

    struct ResourceRecord : public Serialize
    {
      ResourceRecord() = default;
      ResourceRecord(const ResourceRecord& other);
      ResourceRecord(ResourceRecord&& other);

      explicit ResourceRecord(std::string name, RRType_t type, RR_RData_t rdata);

      bool
      Encode(llarp_buffer_t* buf) const override;

      bool
      Decode(llarp_buffer_t* buf) override;

      util::StatusObject
      ToJSON() const override;

      std::string
      ToString() const;

      bool
      HasCNameForTLD(const std::string& tld) const;

      std::string rr_name;
      RRType_t rr_type;
      RRClass_t rr_class;
      RR_TTL_t ttl;
      RR_RData_t rData;
    };
  }  // namespace dns
}  // namespace llarp

template <>
constexpr inline bool llarp::IsToStringFormattable<llarp::dns::ResourceRecord> = true;
```


-------------------------------

Updated on 2022-11-29 at 18:11:27 +0000
